[neon/forks/ubuntu-release-upgrader/Neon/unstable_focal] /: incorporate chad's changes to release cache lock during runPostInstallScripts, drop gnome-software-plugin-snap changes, fix up changelog

Brian Murray null at kde.org
Mon Nov 30 14:22:52 GMT 2020


Git commit c5f611d847dfc133e4902064a6cdb2f757d529da by Brian Murray.
Committed on 08/10/2020 at 22:23.
Pushed by sitter into branch 'Neon/unstable_focal'.

incorporate chad's changes to release cache lock during runPostInstallScripts, drop gnome-software-plugin-snap changes, fix up changelog

M  +8    -0    DistUpgrade/DistUpgradeController.py
M  +0    -1    data/DistUpgrade.cfg.bionic
M  +2    -0    data/mirrors.cfg
M  +20   -1    debian/changelog
M  +2    -2    utils/update_mirrors.py

https://invent.kde.org/neon/forks/ubuntu-release-upgrader/commit/c5f611d847dfc133e4902064a6cdb2f757d529da

diff --git a/DistUpgrade/DistUpgradeController.py b/DistUpgrade/DistUpgradeController.py
index 9f4e76b1..18e1ac3c 100644
--- a/DistUpgrade/DistUpgradeController.py
+++ b/DistUpgrade/DistUpgradeController.py
@@ -1518,7 +1518,13 @@ class DistUpgradeController(object):
         """ 
         scripts that are run in any case after the distupgrade finished 
         whether or not it was successful
+
+        Cache lock is released during script runs in the event that the
+        PostInstallScripts require apt or dpkg changes.
         """
+        if self.cache:
+            self.cache.release_lock()
+            self.cache.unlock_lists_dir()
         # now run the post-upgrade fixup scripts (if any)
         for script in self.config.getlist("Distro","PostInstallScripts"):
             if not os.path.exists(script):
@@ -1531,6 +1537,8 @@ class DistUpgradeController(object):
                 self._view.getTerminal().call([script], hidden=True)
             except Exception as e:
                 logging.error("got error from PostInstallScript %s (%s)" % (script, e))
+        if self.cache:
+            self.cache.get_lock()
 
     def abort(self):
         """ abort the upgrade, cleanup (as much as possible) """
diff --git a/data/DistUpgrade.cfg.bionic b/data/DistUpgrade.cfg.bionic
index 452c7216..038056b6 100644
--- a/data/DistUpgrade.cfg.bionic
+++ b/data/DistUpgrade.cfg.bionic
@@ -97,7 +97,6 @@ PostUpgradeRemove=ibus,lightdm-gtk-greeter,lightdm-gtk-greeter-settings
 
 [ubuntukylin-desktop]
 KeyDependencies=ubuntukylin-keyring, ubuntukylin-wallpapers, ubuntu-kylin-docs
-ForcedObsoletes=gnome-software-plugin-snap
 
 [ubuntu-budgie-desktop]
 KeyDependencies=budgie-desktop-environment, budgie-welcome, ubuntu-budgie-themes
diff --git a/data/mirrors.cfg b/data/mirrors.cfg
index aa935f7b..6f51fd85 100644
--- a/data/mirrors.cfg
+++ b/data/mirrors.cfg
@@ -17,6 +17,8 @@ ftp://ddebs.ubuntu.com/
 #commercial (both urls are valid)
 http://archive.canonical.com
 http://archive.canonical.com/ubuntu/
+
+http://ppa.launchpad.net/ua-client/stable/ubuntu
 https://esm.ubuntu.com/ubuntu/
 https://esm.ubuntu.com/apps/ubuntu/
 https://esm.ubuntu.com/cc/ubuntu/
diff --git a/debian/changelog b/debian/changelog
index 4211ff77..c034801f 100644
--- a/debian/changelog
+++ b/debian/changelog
@@ -1,8 +1,27 @@
-ubuntu-release-upgrader (1:20.04.27) focal; urgency=medium
+ubuntu-release-upgrader (1:20.04.28) focal; urgency=medium
 
+  [ Brian Murray ]
   * DistUpgrade/DistUpgradeQuirks.py: In addition to quirking python-minimal
     we also need to quirk python-dbg, python-doc, and python-dev.
     (LP: #1887544)
+  * drop changes to data/DistUpgrade.cfg.bionic regarding
+    gnome-software-plugin-snap as it failed verification.
+
+  [ Chad Smith ]
+  * data/mirrors.cfg: add all ubuntu-advantage services as valid mirrors.
+    This includes: fips, fips-updates, esm-infra, esm-apps and cc-eal and
+    Ubuntu Pro stable public PPA. (LP: #1893717)
+  * DistUpgrade/DistUpgradeController.py: release cache lock during
+    runPostInstallScripts (LP: #1897778)
+
+ -- Chad Smith <chad.smith at canonical.com>  Wed, 07 Oct 2020 10:49:37 -0600
+
+ubuntu-release-upgrader (1:20.04.27) focal; urgency=medium
+
+  * data/DistUpgrade.cfg.bionic: Add gnome-software-plugin-snap to
+    ForcedObsoletes for ubuntu-desktop and ubuntukylin-desktop only. This
+    allows multiple packages to be offered for removal after the upgrade
+    completes. (LP: #1894919)
 
  -- Brian Murray <brian at ubuntu.com>  Wed, 09 Sep 2020 11:27:27 -0700
 
diff --git a/utils/update_mirrors.py b/utils/update_mirrors.py
index f604ad66..05ceadb0 100755
--- a/utils/update_mirrors.py
+++ b/utils/update_mirrors.py
@@ -15,8 +15,8 @@ d = feedparser.parse("https://launchpad.net/ubuntu/+archivemirrors-rss")
 #pp  = pprint.PrettyPrinter(indent=4)
 #pp.pprint(d)
 
-# the first 29 lines are permanent
-permanent_lines = 29
+# the first 31 lines are permanent
+permanent_lines = 31
 lp_mirrors = set()
 new_mirrors = set()
 



More information about the Neon-commits mailing list